@@ -1,17 +1,13 @@
 #' @rdname loglik-LambertW-utils
-#' @description
-#' \code{loglik_penalty} computes the penalty for transforming the data back to
-#' the input. Note that this penalty is independent of the distribution 
-#' specified by \code{distname}; it only depends on \eqn{\tau}.
+#' @description \code{loglik_penalty} computes the penalty for transforming the
+#'     data back to the input (see Goerg 2016). This penalty is independent of
+#'     the distribution specified by \code{distname}, but only depends on
+#'     \eqn{\tau}. If \code{type = "s"} then the penalty term exists if the
+#'     distribution is non-negative (see \code{get_distname_family}) and
+#'     \code{gamma >= 0}; otherwise, it returns \code{NA}.
 #' 
-#' If \code{type = "s"} then the penalty term exists if the distribution 
-#' is non-negative (see \code{get_distname_family}) and \code{gamma >= 0};
-#' otherwise, it returns \code{NA}.
-#' 
-#' @param is.non.negative logical; tell the penalty function if the data is from 
-#' a non-negative distribution; 
-#' by default it sets it to \code{TRUE} if the distribution is not a location but a scale family. 
-#'  If \code{TRUE}, the penalty can be computed; otherwise, it returns \code{NA}.
+#' @param is.non.negative logical; by default it is set to \code{TRUE} if the
+#'     distribution is not a location but a scale family.
 #' 
 #' @export
 loglik_penalty <- function(tau, y, type = c("h", "hh", "s"),
@@ -32,7 +28,8 @@ loglik_penalty <- function(tau, y, type = c("h", "hh", "s"),
            } else {
              uu <- W_delta(zz, delta = tau["delta"])
              # penalty = sum(log(uu/zz) - log(1 + tau["delta * uu^2))
-             penalty <- sum(-tau["delta"]/2 * uu^2 - log(1 + tau["delta"] * uu^2))
+             penalty <-
+                 sum(-tau["delta"]/2 * uu^2 - log(1 + tau["delta"] * uu^2))
            }
          },
          hh = {
@@ -41,8 +38,10 @@ loglik_penalty <- function(tau, y, type = c("h", "hh", "s"),
            } else {
              uu <- W_2delta(zz, delta = tau[c("delta_l", "delta_r")])
              ind <- (uu < 0)
-             penalty <- sum(-tau["delta_l"]/2 * uu[ind]^2) + sum(-tau["delta_r"]/2 * uu[!ind]^2) - 
-               sum(log(1 + tau["delta_l"] * uu[ind]^2)) - sum(log(1 + tau["delta_r"] * uu[!ind]^2))
+             penalty <- sum(-tau["delta_l"]/2 * uu[ind]^2) +
+                 sum(-tau["delta_r"]/2 * uu[!ind]^2) - 
+                 sum(log(1 + tau["delta_l"] * uu[ind]^2)) -
+                 sum(log(1 + tau["delta_r"] * uu[!ind]^2))
            }
          },
          s = {
@@ -58,4 +57,4 @@ loglik_penalty <- function(tau, y, type = c("h", "hh", "s"),
          })
 
   return(penalty)
-} 
\ No newline at end of file
+} 
